@@ -205,6 +205,8 @@ class VectorField(DataFieldBase):
             This function does not check types or dimensions.
 
         Args:
+            backend (str):
+                The backend (e.g., 'numba' or 'scipy') used for this operator.
             conjugate (bool):
                 Whether to use the complex conjugate for the second operand
 
@@ -297,7 +299,7 @@ class VectorField(DataFieldBase):
                         # correctly and we thus had to use this work-around
                         return np.einsum("i...,i...->...", a, b)  # type: ignore
                     else:
-                        return np.einsum("i...,i...->...", a, b, out=out)
+                        return np.einsum("i...,i...->...", a, b, out=out)  # type: ignore
 
                 elif a.shape == b.shape[1:]:
                     # dot product between vector and tensor
@@ -307,7 +309,7 @@ class VectorField(DataFieldBase):
                         # correctly and we thus had to use this work-around
                         return np.einsum("i...,ij...->j...", a, b)  # type: ignore
                     else:
-                        return np.einsum("i...,ij...->j...", a, b, out=out)
+                        return np.einsum("i...,ij...->j...", a, b, out=out)  # type: ignore
 
                 else:
                     raise ValueError(f"Unsupported shapes ({a.shape}, {b.shape})")
@@ -369,6 +371,10 @@ class VectorField(DataFieldBase):
         Warning:
             This function does not check types or dimensions.
 
+        Args:
+            backend (str):
+                The backend (e.g., 'numba' or 'scipy') used for this operator.
+
         Returns:
             function that takes two instance of :class:`~numpy.ndarray`, which contain
             the discretized data of the two operands. An optional third argument can
@@ -445,7 +451,7 @@ class VectorField(DataFieldBase):
                     # correctly and we thus had to use this work-around
                     return np.einsum("i...,j...->ij...", a, b)  # type: ignore
                 else:
-                    return np.einsum("i...,j...->ij...", a, b, out=out)
+                    return np.einsum("i...,j...->ij...", a, b, out=out)  # type: ignore
 
         else:
             raise ValueError(f"Undefined backend `{backend}")
