@@ -18,6 +18,7 @@ from ..tools.typing import ArrayLike
 from ..trackers.base import TrackerCollectionDataType
 
 if TYPE_CHECKING:
+    from ..solvers.base import SolverBase
     from ..solvers.controller import TRangeType  # @UnusedImport
 
 
@@ -122,6 +123,56 @@ class PDEBase(metaclass=ABCMeta):
         """create a compiled function for evaluating the right hand side"""
         raise NotImplementedError
 
+    def check_rhs_consistency(
+        self,
+        state: FieldBase,
+        t: float = 0,
+        *,
+        tol: float = 1e-7,
+        rhs_numba: Callable = None,
+    ):
+        """check the numba compiled right hand side versus the numpy variant
+
+        Args:
+            state (:class:`~pde.fields.FieldBase`):
+                The state for which the evolution rates should be compared
+            t (float):
+                The associated time point
+            tol (float):
+                Acceptance tolerance. The check passes if the evolution rates differ by
+                less then this value
+            rhs_numba (callable):
+                The implementation of the numba variant that is to be checked. If
+                omitted, an implementation is obtained by calling
+                :meth:`PDEBase._make_pde_rhs_numba_cached`.
+        """
+        # obtain evolution rate from the numpy implementation
+        res_numpy = self.evolution_rate(state.copy(), t).data
+        if not np.all(np.isfinite(res_numpy)):
+            self._logger.warning(
+                "The numpy implementation of the PDE returned non-finite values."
+            )
+
+        # obtain evolution rate from the numba implementation
+        if rhs_numba is None:
+            rhs_numba = self._make_pde_rhs_numba_cached(state)
+        test_state = state.copy()
+        res_numba = rhs_numba(test_state.data, t)
+        if not np.all(np.isfinite(res_numba)):
+            self._logger.warning(
+                "The numba implementation of the PDE returned non-finite values."
+            )
+
+        # compare the two implementations
+        msg = (
+            "The numba compiled implementation of the right hand side is not "
+            "compatible with the numpy implementation. This check can be disabled "
+            "by setting the class attribute `check_implementation` to `False`."
+        )
+        np.testing.assert_allclose(
+            res_numba, res_numpy, err_msg=msg, rtol=tol, atol=tol, equal_nan=True
+        )
+
     def _make_pde_rhs_numba_cached(
         self, state: FieldBase
     ) -> Callable[[np.ndarray, float], np.ndarray]:
@@ -129,6 +180,11 @@ class PDEBase(metaclass=ABCMeta):
 
         This method implements caching and checking of the actual method, which is
         defined by overwriting the method `_make_pde_rhs_numba`.
+
+        Args:
+            state (:class:`~pde.fields.FieldBase`):
+                An example for the state from which the grid and other information can
+                be extracted.
         """
         check_implementation = self.check_implementation
 
@@ -151,30 +207,8 @@ class PDEBase(metaclass=ABCMeta):
             rhs = self._make_pde_rhs_numba(state)
 
         if check_implementation:
-            # obtain and check result from the numpy implementation
-            res_numpy = self.evolution_rate(state.copy(), 0.0).data
-            if not np.all(np.isfinite(res_numpy)):
-                self._logger.warning(
-                    "The numpy implementation of the PDE returned non-finite values."
-                )
+            self.check_rhs_consistency(state, rhs_numba=rhs)
 
-            # obtain and check result from the numba implementation
-            test_state = state.copy()
-            res_numba = rhs(test_state.data, 0.0)
-            if not np.all(np.isfinite(res_numba)):
-                self._logger.warning(
-                    "The numba implementation of the PDE returned non-finite values."
-                )
-
-            # compare the two implementations
-            msg = (
-                "The numba compiled implementation of the right hand side is not "
-                "compatible with the numpy implementation. This check can be disabled "
-                "by setting the class attribute `check_implementation` to `False`."
-            )
-            np.testing.assert_allclose(
-                res_numba, res_numpy, err_msg=msg, rtol=1e-7, atol=1e-7, equal_nan=True
-            )
         return rhs  # type: ignore
 
     def make_pde_rhs(
@@ -184,11 +218,12 @@ class PDEBase(metaclass=ABCMeta):
 
         Args:
             state (:class:`~pde.fields.FieldBase`):
-                An example for the state from which the grid and other
-                information can be extracted
-            backend (str): Determines how the function is created. Accepted
-                values are 'python` and 'numba'. Alternatively, 'auto' lets the
-                code decide for the most optimal backend.
+                An example for the state from which the grid and other information can
+                be extracted.
+            backend (str):
+                Determines how the function is created. Accepted values are 'numpy`
+                and 'numba'. Alternatively, 'auto' lets the code decide for the most
+                optimal backend.
 
         Returns:
             Function determining the right hand side of the PDE
@@ -292,7 +327,7 @@ class PDEBase(metaclass=ABCMeta):
                 @jit
                 def noise_realization(state_data: np.ndarray, t: float) -> np.ndarray:
                     """helper function returning a noise realization"""
-                    return noise_strength * np.random.randn(*data_shape)
+                    return noise_strength * np.random.randn(*data_shape)  # type: ignore
 
             elif isinstance(state, FieldCollection):
                 # different noise strengths, assuming one for each field
@@ -308,7 +343,7 @@ class PDEBase(metaclass=ABCMeta):
                     for i in range(data_shape[0]):
                         # TODO: Avoid creating random numbers when noise_strengths == 0
                         out[i] *= noise_strengths[i]
-                    return out
+                    return out  # type: ignore
 
             else:
                 # different noise strengths, but a single field
@@ -430,8 +465,8 @@ class PDEBase(metaclass=ABCMeta):
         state: FieldBase,
         t_range: "TRangeType",
         dt: float = None,
-        tracker: TrackerCollectionDataType = ["progress", "consistency"],
-        method: str = "auto",
+        tracker: TrackerCollectionDataType = "auto",
+        method: Union[str, "SolverBase"] = "auto",
         ret_info: bool = False,
         **kwargs,
     ) -> Union[FieldBase, Tuple[FieldBase, Dict[str, Any]]]:
@@ -456,31 +491,36 @@ class PDEBase(metaclass=ABCMeta):
                 based on the stepper will be chosen. In particular, if
                 `method == 'auto'`, the :class:`~pde.solvers.ScipySolver` with an
                 automatic, adaptive time step is used. This is a flexible choice, but
-                might be slower than using a fixed time step.
+                might be slower than using a fixed time step, where the explicit solver
+                :class:`~pde.solvers.explicit.ExplicitSolver` is when `method == 'auto'`.
             tracker:
                 Defines a tracker that process the state of the simulation at specified
                 time intervals. A tracker is either an instance of
                 :class:`~pde.trackers.base.TrackerBase` or a string, which identifies a
                 tracker. All possible identifiers can be obtained by calling
                 :func:`~pde.trackers.base.get_named_trackers`. Multiple trackers can be
-                specified as a list. The default value is `['progress', 'consistency']`,
-                which displays a progress bar and checks the state for consistency,
-                aborting the simulation when not-a-number values appear. More general
-                trackers are defined in :mod:`~pde.trackers`, where all options are
-                explained in detail. In particular, the interval at which the tracker is
-                evaluated can be chosen when creating a tracker object explicitly.
+                specified as a list. The default value `auto` checks the state for
+                consistency (tracker 'consistency') and displays a progress bar (tracker
+                'progress') when :mod:`tqdm` is installed. More general trackers are
+                defined in :mod:`~pde.trackers`, where all options are explained in
+                detail. In particular, the interval at which the tracker is evaluated
+                can be chosen when creating a tracker object explicitly.
             method (:class:`~pde.solvers.base.SolverBase` or str):
-                Specifies a method for solving the differential equation. This
-                can either be an instance of
-                :class:`~pde.solvers.base.SolverBase` or a descriptive name
-                like 'explicit' or 'scipy'. The valid names are given by
-                :meth:`pde.solvers.base.SolverBase.registered_solvers`.
+                Specifies a method for solving the differential equation. This can
+                either be an instance of :class:`~pde.solvers.base.SolverBase` or a
+                descriptive name like 'explicit' or 'scipy'. The valid names are given
+                by :meth:`pde.solvers.base.SolverBase.registered_solvers`. The default
+                value 'auto' selects :class:`~pde.solvers.ScipySolver` if `dt` is not
+                specified and otherwise :class:`~pde.solvers.explicit.ExplicitSolver`.
             ret_info (bool):
                 Flag determining whether diagnostic information about the solver
                 process should be returned.
             **kwargs:
                 Additional keyword arguments are forwarded to the solver class chosen
-                with the `method` argument.
+                with the `method` argument. In particular, several `schemes` can be
+                selected for the :class:`~pde.solvers.explicit.ExplicitSolver` and the
+                additional arguments of :func:`scipy.integrate.solve_ivp` are accepted
+                for :class:`~pde.solvers.ScipySolver`.
 
         Returns:
             :class:`~pde.fields.base.FieldBase`:
@@ -497,12 +537,16 @@ class PDEBase(metaclass=ABCMeta):
         if callable(method):
             solver = method(pde=self, **kwargs)
             if not isinstance(solver, SolverBase):
-                self._logger.warn(
+                self._logger.warning(
                     "Solver is not an instance of `SolverBase`. Specified wrong method?"
                 )
-        else:
+
+        elif isinstance(method, str):
             solver = SolverBase.from_name(method, pde=self, **kwargs)
 
+        else:
+            raise TypeError(f"Method {method} is not supported")
+
         # create controller
         from ..solvers import Controller
 
