@@ -28,7 +28,7 @@ class ExplicitSolver(SolverBase):
         scheme: str = "euler",
         backend: str = "auto",
         adaptive: bool = False,
-        tolerance: float = 1e-3,
+        tolerance: float = 1e-4,
     ):
         """
         Args:
@@ -432,6 +432,12 @@ class ExplicitSolver(SolverBase):
         # the solver should use a default time step
         if dt is None:
             dt = 1e-3
+            if not self.adaptive:
+                self._logger.warn(
+                    "Explicit stepper with a fixed time step did not receive any "
+                    f"initial value for `dt`. Using dt={dt}, but specifying a value or "
+                    "enabling adaptive stepping is advisable."
+                )
 
         self.info["dt"] = dt
         self.info["steps"] = 0
