@@ -15,6 +15,7 @@ representations using :mod:`sympy`.
 .. codeauthor:: David Zwicker <david.zwicker@ds.mpg.de> 
 """
 
+from __future__ import annotations
 
 import builtins
 import copy
@@ -22,7 +23,7 @@ import json
 import logging
 import numbers
 import re
-from abc import ABCMeta, abstractproperty
+from abc import ABCMeta, abstractmethod
 from pathlib import Path
 from typing import (  # @UnusedImport
     TYPE_CHECKING,
@@ -264,7 +265,8 @@ class ExpressionBase(metaclass=ABCMeta):
         """bool: whether the expression contains the imaginary unit I"""
         return sympy.I in self._sympy_expr.atoms()
 
-    @abstractproperty
+    @property
+    @abstractmethod
     def shape(self) -> Tuple[int, ...]:
         pass
 
@@ -560,6 +562,11 @@ class ScalarExpression(ExpressionBase):
             consts=consts,
         )
 
+    def copy(self) -> ScalarExpression:
+        """return a copy of the current expression"""
+        # __init__ copies all relevant attributes
+        return self.__class__(self)
+
     @property
     def value(self) -> Number:
         """float: the value for a constant expression"""
